@@ -18,7 +18,7 @@ _cachekey_func = None
 
 
 def get_hexdigest(plaintext, length=None):
-    digest = hashlib.md5(smart_bytes(plaintext)).hexdigest()
+    digest = hashlib.sha256(smart_bytes(plaintext)).hexdigest()
     if length:
         return digest[:length]
     return digest
@@ -50,7 +50,10 @@ def get_mtime_cachekey(filename):
 
 
 def get_offline_hexdigest(render_template_string):
-    return get_hexdigest(render_template_string)
+    return get_hexdigest(
+        # Make the hexdigest determination independent of STATIC_URL
+        render_template_string.replace(settings.STATIC_URL, '')
+    )
 
 
 def get_offline_cachekey(source):
