@@ -3,10 +3,10 @@ from __future__ import absolute_import, unicode_literals
 from django.core.exceptions import ImproperlyConfigured
 from django.utils import six
 from django.utils.encoding import smart_text
+from django.utils.functional import cached_property
 
 from compressor.exceptions import ParserError
 from compressor.parser import ParserBase
-from compressor.utils.decorators import cached_property
 
 
 class LxmlParser(ParserBase):
