@@ -8,7 +8,7 @@ class TestMtimeCacheCommand(TestCase):
     # FIXME: add actual tests, improve the existing ones.
 
     exclusion_patterns = [
-        '*CACHE*', '*custom*', '*066cd253eada.js', 'test.txt*'
+        '*CACHE*', '*custom*', '*066cd253eada.js', '*d728fc7f9301.js', '*74e158ccb432.js', 'test.txt*'
     ]
 
     def default_ignore(self):
@@ -24,8 +24,8 @@ class TestMtimeCacheCommand(TestCase):
             call_command(
                 'mtime_cache', '--add', *self.default_ignore(), stdout=out)
         output = out.getvalue()
-        self.assertIn('Deleted mtimes of 19 files from the cache.', output)
-        self.assertIn('Added mtimes of 19 files to cache.', output)
+        self.assertIn('Deleted mtimes of 20 files from the cache.', output)
+        self.assertIn('Added mtimes of 20 files to cache.', output)
 
     def test_handle_clean(self):
         out = StringIO()
@@ -33,5 +33,5 @@ class TestMtimeCacheCommand(TestCase):
             call_command(
                 'mtime_cache', '--clean', *self.default_ignore(), stdout=out)
         output = out.getvalue()
-        self.assertIn('Deleted mtimes of 19 files from the cache.', output)
-        self.assertNotIn('Added mtimes of 19 files to cache.', output)
+        self.assertIn('Deleted mtimes of 20 files from the cache.', output)
+        self.assertNotIn('Added mtimes of 20 files to cache.', output)
